@@ -387,13 +387,13 @@ class ProjectTopping(QObject):
                     maptheme_item[layername]["visible"] = layerrecord.isVisible
                     maptheme_item[layername]["expanded"] = layerrecord.expandedLayerNode
                     if layerrecord.expandedLegendItems:
-                        maptheme_item[layername][
-                            "expanded_items"
-                        ] = layerrecord.expandedLegendItems
+                        maptheme_item[layername]["expanded_items"] = list(
+                            layerrecord.expandedLegendItems
+                        )
                     if layerrecord.usingLegendItems:
-                        maptheme_item[layername][
-                            "checked_items"
-                        ] = layerrecord.checkedLegendItems
+                        maptheme_item[layername]["checked_items"] = list(
+                            layerrecord.checkedLegendItems
+                        )
 
                 if maptheme_record.hasExpandedStateInfo():
                     for expanded_groupnode in maptheme_record.expandedGroupNodes():
@@ -419,9 +419,11 @@ class ProjectTopping(QObject):
         ):
             self.clear()
             for variable_key in export_settings.variables:
-                self[variable_key] = QgsExpressionContextUtils.projectScope(
+                variable_value = QgsExpressionContextUtils.projectScope(
                     project
                 ).variable(variable_key)
+                if variable_value:
+                    self[variable_key] = variable_value
 
     class Layouts(dict):
         """
